@@ -30,16 +30,8 @@ char copyright[] =
 /*
  *
  * Linux port:
- * v 0.0	May 11th 1994	bjdouma@xs4all.hacktic.nl
- * v 0.2	May 19th 1994	bjdouma@xs4all.hacktic.nl
- * v 0.3	May 26th 1994	bjdouma@xs4all.hacktic.nl
- * v 0.4	Jun  4th 1994	bjdouma@xs4all.hacktic.nl
- * v 0.5	Jun 16th 1994	bjdouma@xs4all.hacktic.nl
- * v 0.6	Aug 30th 1994	bjdouma@xs4all.hacktic.nl
- * v 0.7	Mar  9th 1995	bjdouma@xs4all.nl
- * v 0.8	Apr 20th 1995	bjdouma@xs4all.nl
- * v 0.9	Apr 23th 1995	bjdouma@xs4all.nl
- * v 1.0	May 11th 1995	bjdouma@xs4all.nl
+ * v 1.0	May 11th 1995	bjdouma@xs4all.nl (Bauke Jan Douma)
+ * v 1.1	Mar 16th 1996	bjdouma@xs4all.nl (Bauke Jan Douma)
  *
  */
 
@@ -1377,11 +1369,17 @@ strcpy1(p, q)
 	return p - 1;
 }
 
+/* 
+ * inspired upon ncurses's unctrl() -- bjd
+ */
+#undef  unctrl
+#define unctrl(x)	((x&0x60)!=0&&x!=0x7F)?(x):(x==0x7F?'?':(x|0x40))
+
 int outc(c)
 	char c;
 {
 	if (dbug)
-		printf("%s", unctrl(c));
+		printf("%c", unctrl(c));
 	else
 		putchar(c);
 	return( 1 );
@@ -1391,7 +1389,7 @@ int erroutc(c)
 	char c;
 {
 	if (dbug)
-		fprintf(stderr, "%s", unctrl(c));
+		fprintf(stderr, "%c", unctrl(c));
 	else
 		putc(c, stderr);
 	return( 1 );
@@ -1457,10 +1455,10 @@ int erroutc(c)
 				 /*
 				  * Sleep can mean waiting for a signal or just
 				  * in a disk or page wait queue ready to run.
-				  * We can tell if it is the later by the pri
+				  * We can tell if it is the latter by the pri
 				  * being negative.
 				  */
-				 if (process_priority > PZERO)
+				 if (process_priority > 0/*PZERO*/)
 					procrun++;
 				 break;
 			case 'D':
@@ -1503,7 +1501,7 @@ int erroutc(c)
 			t += sprintf( t, "\033[" );
 			for ( i=0; i<n; i++ )
 				t += sprintf( t, "%d;", val[i] );
-			t += sprintf( t-1, "m" );
+			*(t-1) = 'm';
 		
 			return( 1 );
 		}
